Classes
=======================================================================

A science class is where the core science is done as a task  
It will be called by a workflow when it is run.
However, it will have no knowledge of workflow semantics or structure.

TBD